==> ec2-1.8.0.DEVPREVIEW-sources.jar: software/amazon/awscdk/services/ec2/AclPortRange.java <==
package software.amazon.awscdk.services.ec2;

/**
 * Properties to create PortRange.
 * 
 * EXPERIMENTAL
 */
@javax.annotation.Generated(value = "jsii-pacmak/0.16.0 (build 98909b5)", date = "2019-09-10T21:16:48.700Z")
@software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
public interface AclPortRange extends software.amazon.jsii.JsiiSerializable {
    /**
     * The first port in the range.
     * 
     * Required if you specify 6 (TCP) or 17 (UDP) for the protocol parameter.
     * 
     * EXPERIMENTAL
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
    java.lang.Number getFrom();

    /**
     * The last port in the range.
     * 
     * Required if you specify 6 (TCP) or 17 (UDP) for the protocol parameter.
     * 
     * EXPERIMENTAL
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
    java.lang.Number getTo();

    /**
     * @return a {@link Builder} of {@link AclPortRange}
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
    static Builder builder() {
        return new Builder();
    }

    /**
     * A builder for {@link AclPortRange}
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
    final class Builder {
        private java.lang.Number from;
        private java.lang.Number to;

        /**
         * Sets the value of From
         * @param from The first port in the range.
         * @return {@code this}
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
        public Builder from(java.lang.Number from) {
            this.from = from;
            return this;
        }

        /**
         * Sets the value of To
         * @param to The last port in the range.
         * @return {@code this}
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
        public Builder to(java.lang.Number to) {
            this.to = to;
            return this;
        }

        /**
         * Builds the configured instance.
         * @return a new instance of {@link AclPortRange}
         * @throws NullPointerException if any required attribute was not provided
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
        public AclPortRange build() {
            return new Jsii$Proxy(from, to);
        }

    }

    /**
     * An implementation for {@link AclPortRange}
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
    final class Jsii$Proxy extends software.amazon.jsii.JsiiObject implements AclPortRange {
        private final java.lang.Number from;
        private final java.lang.Number to;

        /**
         * Constructor that initializes the object based on values retrieved from the JsiiObject.
         * @param objRef Reference to the JSII managed object.
         */
        protected Jsii$Proxy(final software.amazon.jsii.JsiiObjectRef objRef) {
            super(software.amazon.jsii.JsiiObject.InitializationMode.JSII);
            this.setObjRef(objRef);
            this.from = this.jsiiGet("from", java.lang.Number.class);
            this.to = this.jsiiGet("to", java.lang.Number.class);
        }


        /**
         * Constructor that initializes the object based on literal property values passed by the {@link Builder}.
         */
        private Jsii$Proxy(java.lang.Number from, java.lang.Number to) {
            super(software.amazon.jsii.JsiiObject.InitializationMode.JSII);
            this.from = from;
            this.to = to;
        }

        @Override
        public java.lang.Number getFrom() {
            return this.from;
        }

        @Override
        public java.lang.Number getTo() {
            return this.to;
        }

        @Override
        public com.fasterxml.jackson.databind.JsonNode $jsii$toJson() {
            com.fasterxml.jackson.databind.ObjectMapper om = software.amazon.jsii.JsiiObjectMapper.INSTANCE;
            com.fasterxml.jackson.databind.node.ObjectNode obj = com.fasterxml.jackson.databind.node.JsonNodeFactory.instance.objectNode();
            if (this.getFrom() != null) {
                obj.set("from", om.valueToTree(this.getFrom()));
            }
            if (this.getTo() != null) {
                obj.set("to", om.valueToTree(this.getTo()));
            }
            return obj;
        }

        @Override
        public boolean equals(Object o) {
            if (this == o) return true;
            if (o == null || getClass() != o.getClass()) return false;

            AclPortRange.Jsii$Proxy that = (AclPortRange.Jsii$Proxy) o;

            if (this.from != null ? !this.from.equals(that.from) : that.from != null) return false;
            return this.to != null ? this.to.equals(that.to) : that.to == null;
        }

        @Override
        public int hashCode() {
            int result = this.from != null ? this.from.hashCode() : 0;
            result = 31 * result + (this.to != null ? this.to.hashCode() : 0);
            return result;
        }

    }
}

==> ec2-1.9.0.DEVPREVIEW-sources.jar: software/amazon/awscdk/services/ec2/AclPortRange.java <==
package software.amazon.awscdk.services.ec2;

/**
 * Properties to create PortRange.
 * 
 * EXPERIMENTAL
 */
@javax.annotation.Generated(value = "jsii-pacmak/0.17.0 (build 7d5d104)", date = "2019-09-20T09:56:18.894Z")
@software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
public interface AclPortRange extends software.amazon.jsii.JsiiSerializable {

    /**
     * The first port in the range.
     * 
     * Required if you specify 6 (TCP) or 17 (UDP) for the protocol parameter.
     * 
     * EXPERIMENTAL
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
    java.lang.Number getFrom();

    /**
     * The last port in the range.
     * 
     * Required if you specify 6 (TCP) or 17 (UDP) for the protocol parameter.
     * 
     * EXPERIMENTAL
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
    java.lang.Number getTo();

    /**
     * @return a {@link Builder} of {@link AclPortRange}
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
    static Builder builder() {
        return new Builder();
    }
    /**
     * A builder for {@link AclPortRange}
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
    public static final class Builder {
        private java.lang.Number from;
        private java.lang.Number to;

        /**
         * Sets the value of From
         * @param from The first port in the range.
         * @return {@code this}
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
        public Builder from(java.lang.Number from) {
            this.from = from;
            return this;
        }

        /**
         * Sets the value of To
         * @param to The last port in the range.
         * @return {@code this}
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
        public Builder to(java.lang.Number to) {
            this.to = to;
            return this;
        }

        /**
         * Builds the configured instance.
         * @return a new instance of {@link AclPortRange}
         * @throws NullPointerException if any required attribute was not provided
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
        public AclPortRange build() {
            return new Jsii$Proxy(from, to);
        }
    }

    /**
     * An implementation for {@link AclPortRange}
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
    final class Jsii$Proxy extends software.amazon.jsii.JsiiObject implements AclPortRange {
        private final java.lang.Number from;
        private final java.lang.Number to;

        /**
         * Constructor that initializes the object based on values retrieved from the JsiiObject.
         * @param objRef Reference to the JSII managed object.
         */
        protected Jsii$Proxy(final software.amazon.jsii.JsiiObjectRef objRef) {
            super(software.amazon.jsii.JsiiObject.InitializationMode.JSII);
            this.setObjRef(objRef);
            this.from = this.jsiiGet("from", java.lang.Number.class);
            this.to = this.jsiiGet("to", java.lang.Number.class);
        }

        /**
         * Constructor that initializes the object based on literal property values passed by the {@link Builder}.
         */
        private Jsii$Proxy(java.lang.Number from, java.lang.Number to) {
            super(software.amazon.jsii.JsiiObject.InitializationMode.JSII);
            this.from = from;
            this.to = to;
        }

        @Override
        public java.lang.Number getFrom() {
            return this.from;
        }

        @Override
        public java.lang.Number getTo() {
            return this.to;
        }

        @Override
        public com.fasterxml.jackson.databind.JsonNode $jsii$toJson() {
            com.fasterxml.jackson.databind.ObjectMapper om = software.amazon.jsii.JsiiObjectMapper.INSTANCE;
            com.fasterxml.jackson.databind.node.ObjectNode obj = com.fasterxml.jackson.databind.node.JsonNodeFactory.instance.objectNode();
            if (this.getFrom() != null) {
                obj.set("from", om.valueToTree(this.getFrom()));
            }
            if (this.getTo() != null) {
                obj.set("to", om.valueToTree(this.getTo()));
            }
            return obj;
        }

        @Override
        public boolean equals(Object o) {
            if (this == o) return true;
            if (o == null || getClass() != o.getClass()) return false;

            AclPortRange.Jsii$Proxy that = (AclPortRange.Jsii$Proxy) o;

            if (this.from != null ? !this.from.equals(that.from) : that.from != null) return false;
            return this.to != null ? this.to.equals(that.to) : that.to == null;
        }

        @Override
        public int hashCode() {
            int result = this.from != null ? this.from.hashCode() : 0;
            result = 31 * result + (this.to != null ? this.to.hashCode() : 0);
            return result;
        }
    }
}
